.. examples:

========
Examples
========

Simple uses of the ``dataretrieval`` package
--------------------------------------------

.. toctree::
    :maxdepth: 2

    readme_examples
    siteinfo_examples


Example Notebooks from Hydroshare
---------------------------------
A set of Jupyter Notebooks with Python code examples on how to use the
``dataretrieval`` package are available on the `Hydroshare`_ platform.
We provide executed versions of these notebooks below; to download the
``.ipynb`` files for your own use, either visit the `Hydroshare`_ repository,
or navigate to the `demos/hydroshare`_ subdirectory of the ``dataretrieval``
project repository.

.. _Hydroshare: https://www.hydroshare.org/resource/c97c32ecf59b4dff90ef013030c54264/

.. _demos/hydroshare: https://github.com/DOI-USGS/dataretrieval-python/tree/master/demos/hydroshare

.. toctree::
    :maxdepth: 1

    USGS_dataretrieval_DailyValues_Examples
    USGS_dataretrieval_GroundwaterLevels_Examples
    USGS_dataretrieval_Measurements_Examples
    USGS_dataretrieval_ParameterCodes_Examples
    USGS_dataretrieval_Peaks_Examples
    USGS_dataretrieval_Ratings_Examples
    USGS_dataretrieval_SiteInfo_Examples
    USGS_dataretrieval_SiteInventory_Examples
    USGS_dataretrieval_Statistics_Examples
    USGS_dataretrieval_UnitValues_Examples
    USGS_dataretrieval_WaterSamples_Examples
    USGS_dataretrieval_WaterUse_Examples


Using ``dataretrieval`` to obtain nation trends in peak annual streamflow
-------------------------------------------------------------------------

.. toctree::
    :maxdepth: 2

    nwisdemo01


Duplicating the R ``dataRetrieval`` vignettes functionality
-----------------------------------------------------------

.. note::

    Some of the larger (e.g., state-wide) examples have been commented out
    in the interest of run-time for the notebook.

.. toctree::
    :maxdepth: 2

    rvignettes